| File 1 |  | File 2
--- | --- | --- | ---
f | 1 | Cisco IOS Software, C3900 Software (C3900-UNIVERSALK9-M), Version 15.7(3)M8, REL | f | 1 | Cisco IOS Software, C3900 Software (C3900-UNIVERSALK9-M), Version 15.7(3)M8, REL
| > | EASE SOFTWARE (fc1) |  | > | EASE SOFTWARE (fc1)
| 2 | Technical Support: http://www.cisco.com/techsupport |  | 2 | Technical Support: http://www.cisco.com/techsupport
| 3 | Copyright (c) 1986-2021 by Cisco Systems, Inc. |  | 3 | Copyright (c) 1986-2021 by Cisco Systems, Inc.
| 4 | Compiled Tue 02-Mar-21 05:51 by prod_rel_team |  | 4 | Compiled Tue 02-Mar-21 05:51 by prod_rel_team
| 5 |  |  | 5 |
| 6 | ROM: System Bootstrap, Version 15.0(1r)M16, RELEASE SOFTWARE (fc1) |  | 6 | ROM: System Bootstrap, Version 15.0(1r)M16, RELEASE SOFTWARE (fc1)
| 7 |  |  | 7 |
n | 8 | cnac-vpn-rtr-01 uptime is 1 year, 28 weeks, 4 days, 3 hours, 11 minutes | n | 8 | cnac-vpn-rtr-02 uptime is 6 weeks, 2 days, 2 hours, 41 minutes
| 9 | System returned to ROM by reload at 05:00:00 PDT Fri Apr 8 2022 |  | 9 | System returned to ROM by address error at PC 0x44CA538, address 0xED07320 at 05
|  |  |  | > | :27:42 PDT Mon Sep 11 2023
| 10 | System restarted at 05:02:32 PDT Fri Apr 8 2022 |  | 10 | System restarted at 05:30:14 PDT Mon Sep 11 2023
| 11 | System image file is "flash:c3900-universalk9-mz.SPA.157-3.M8.bin" |  | 11 | System image file is "flash:c3900-universalk9-mz.SPA.157-3.M8.bin"
| 12 | Last reload type: Normal Reload |  | 12 | Last reload type: Normal Reload
n | 13 | Last reload reason: Reload Command | n | 13 | Last reload reason: address error at PC 0x44CA538, address 0xED07320
| 14 |  |  | 14 |
| 15 |  |  | 15 |
| 16 |  |  | 16 |
| 17 | This product contains cryptographic features and is subject to United |  | 17 | This product contains cryptographic features and is subject to United
| 18 | States and local country laws governing import, export, transfer and |  | 18 | States and local country laws governing import, export, transfer and
| 19 | use. Delivery of Cisco cryptographic products does not imply |  | 19 | use. Delivery of Cisco cryptographic products does not imply
| 20 | third-party authority to import, export, distribute or use encryption. |  | 20 | third-party authority to import, export, distribute or use encryption.
| 21 | Importers, exporters, distributors and users are responsible for |  | 21 | Importers, exporters, distributors and users are responsible for
| 22 | compliance with U.S. and local country laws. By using this product you |  | 22 | compliance with U.S. and local country laws. By using this product you
| 23 | agree to comply with applicable laws and regulations. If you are unable |  | 23 | agree to comply with applicable laws and regulations. If you are unable
| 24 | to comply with U.S. and local laws, return this product immediately. |  | 24 | to comply with U.S. and local laws, return this product immediately.
| 25 |  |  | 25 |
| 26 | A summary of U.S. laws governing Cisco cryptographic products may be found at: |  | 26 | A summary of U.S. laws governing Cisco cryptographic products may be found at:
| 27 | http://www.cisco.com/wwl/export/crypto/tool/stqrg.html |  | 27 | http://www.cisco.com/wwl/export/crypto/tool/stqrg.html
| 28 |  |  | 28 |
| 29 | If you require further assistance please contact us by sending email to |  | 29 | If you require further assistance please contact us by sending email to
| 30 | export@cisco.com. |  | 30 | export@cisco.com.
| 31 |  |  | 31 |
n | 32 | Cisco CISCO3925-CHASSIS (revision 1.0) with C3900-SPE100/K9 with 997376K/51200K | n | 32 | Cisco CISCO3925-CHASSIS (revision 1.0) with C3900-SPE100/K9 with 999424K/49152K
| > | bytes of memory. |  | > | bytes of memory.
| 33 | Processor board ID FTX1817AJWA |  | 33 | Processor board ID FTX1817AJWC
| 34 | 4 Gigabit Ethernet interfaces |  | 34 | 3 Gigabit Ethernet interfaces
| 35 | 1 terminal line |  | 35 | 1 terminal line
| 36 | 1 Virtual Private Network (VPN) Module |  | 36 | 1 Virtual Private Network (VPN) Module
| 37 | DRAM configuration is 72 bits wide with parity enabled. |  | 37 | DRAM configuration is 72 bits wide with parity enabled.
| 38 | 255K bytes of non-volatile configuration memory. |  | 38 | 255K bytes of non-volatile configuration memory.
| 39 | 255488K bytes of ATA System CompactFlash 0 (Read/Write) |  | 39 | 255488K bytes of ATA System CompactFlash 0 (Read/Write)
| 40 |  |  | 40 |
| 41 |  |  | 41 |
| 42 | License Info: |  | 42 | License Info:
| 43 |  |  | 43 |
| 44 | License UDI: |  | 44 | License UDI:
| 45 |  |  | 45 |
| 46 | ------------------------------------------------- |  | 46 | -------------------------------------------------
| 47 | Device# PID SN |  | 47 | Device# PID SN
| 48 | ------------------------------------------------- |  | 48 | -------------------------------------------------
t | 49 | *1 C3900-SPE100/K9 FOC18072CVY | t | 49 | *1 C3900-SPE100/K9 FOC18072CNB
| 50 |  |  | 50 |
| 51 |  |  | 51 |
| 52 |  |  | 52 |
| 53 |  |  | 53 |
| 54 | Suite License Information for Module:'c3900' |  | 54 | Suite License Information for Module:'c3900'
| 55 |  |  | 55 |
| 56 | -------------------------------------------------------------------------------- |  | 56 | --------------------------------------------------------------------------------
| 57 | Suite Suite Current Type Suite Next reboot |  | 57 | Suite Suite Current Type Suite Next reboot
| > |  |  | > |
| 58 | -------------------------------------------------------------------------------- |  | 58 | --------------------------------------------------------------------------------
| 59 | FoundationSuiteK9 None None None |  | 59 | FoundationSuiteK9 None None None
| > |  |  | > |
| 60 | securityk9 |  | 60 | securityk9
| 61 | datak9 |  | 61 | datak9
| 62 |  |  | 62 |
| 63 | AdvUCSuiteK9 None None None |  | 63 | AdvUCSuiteK9 None None None
| > |  |  | > |
| 64 | uck9 |  | 64 | uck9
| 65 | cme-srst |  | 65 | cme-srst
| 66 | cube |  | 66 | cube
| 67 |  |  | 67 |
| 68 |  |  | 68 |
| 69 | Technology Package License Information for Module:'c3900' |  | 69 | Technology Package License Information for Module:'c3900'
| 70 |  |  | 70 |
| 71 | ------------------------------------------------------------------------ |  | 71 | ------------------------------------------------------------------------
| 72 | Technology Technology-package Technology-package |  | 72 | Technology Technology-package Technology-package
| 73 | Current Type Next reboot |  | 73 | Current Type Next reboot
| 74 | ------------------------------------------------------------------------ |  | 74 | ------------------------------------------------------------------------
| 75 | ipbase ipbasek9 Permanent ipbasek9 |  | 75 | ipbase ipbasek9 Permanent ipbasek9
| 76 | security securityk9 Permanent securityk9 |  | 76 | security securityk9 Permanent securityk9
| 77 | uc None None None |  | 77 | uc None None None
| 78 | data datak9 Permanent datak9 |  | 78 | data datak9 Permanent datak9
| 79 |  |  | 79 |
| 80 | Configuration register is 0x2102 |  | 80 | Configuration register is 0x2102

Legends
Colors
Added
Changed
Deleted
Links
(f)irst change
(n)ext change
(t)op